==> landtax-1.0.0-20160602.090753-7-sources.jar: cn/gtmap/landtax/service/impl/SwgxServiceImpl.java <==
package cn.gtmap.landtax.service.impl;

import cn.gtmap.landtax.entity.SwDjFc;
import cn.gtmap.landtax.entity.SwDjSy;
import cn.gtmap.landtax.entity.SwDjTd;
import cn.gtmap.landtax.service.SwgxService;
import cn.gtmap.landtax.service.TaxService;
import cn.gtmap.landtax.service.TjService;
import cn.gtmap.landtax.support.jpa.BaseRepository;
import cn.gtmap.landtax.util.QueryCondition;
import org.hibernate.SQLQuery;
import org.hibernate.transform.Transformers;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.persistence.Query;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * Created by zhouzhiwei on 2015-11-2.
 */
@Service
public class SwgxServiceImpl implements SwgxService {
    @Autowired
    BaseRepository baseRepository;
    @Autowired
    TjService tjService;
    @Autowired
    TaxService taxService;

    @Override
    @Transactional
    public void updateSwData() {
        String tag = null;
        String sql = null;
        Query query = null;
        List<QueryCondition> queryConditionList = new ArrayList<QueryCondition>();
        try {
            // 更新纳税人数据
            tag = "swgxNsrXz";
            sql = tjService.getTjSql(tag);
            sql = "INSERT INTO SW_DJ_JBB (JBB_ID, GLBM, NSRMC, ZGKG_MC, ZGKG_DM, FDDBR, ZCLX_DM, ZCLX_MC, HY_DM, HY_MC, ZCDZ, NSRZT_DM) " +
                    "SELECT SYS_GUID(), SWGLM, NSR_MC, JIANCJG_MC, JIANCJG_DM, FDDBR, DJZCLX_DM, ZCLX_MC, HY_DM, HY_MC, ZCDZ, NSRZT_DM " +
                    "FROM (" + sql + ")";
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();

            // 更新土地税新增数据
            tag = "swgxTdsXz";
            sql = tjService.getTjSql(tag);
            sql = "INSERT INTO SW_DJ_TD (SY_ID, TD_ID, TDSYZH, TDZL, SCMJ, YNMJ, MSMJ, BZ) " +
                    "SELECT SYS_GUID(), TD_BM, TDSYZH, TDZL, SCMJ, (SCMJ-NVL(MSMJ,0)), MSMJ, SWGLM " +
                    "FROM (" + sql + ")";
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();

            // 更新房产税新增数据
            tag = "swgxFcsXz";
            sql = tjService.getTjSql(tag);
            sql = "INSERT INTO SW_DJ_FC (SY_ID, FC_ID, FCZH, FCZL, FCMJ, QZCZFCMJ, FCYZ, FCYZ_YS, FCYZ_MS, JSBL, SL, NYNSE, BZ) " +
                    "SELECT SYS_GUID(), FY_BM, CQZSH, FWZL, JZ_MJ, CZ_MJ, YSFCYZ_JE, YSFCYZ_JE-NVL(MSYZ_JE,0), MSYZ_JE, JSBL, SL, ROUND((YSFCYZ_JE-NVL(MSYZ_JE,0))*JSBL*SL, 2), SWGLM " +
                    "FROM (" + sql + ")";
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();

            // 更新税源主表数据
            sql = "INSERT INTO SW_DJ_SY (SY_ID, JBB_ID, SJLY, SYZT, SGZT_DM, UPDATE_RQ, UPDATE_USERNAME, CZLX, BZ) " +
                    "SELECT t.SY_ID, t2.JBB_ID, '0' AS SJLY, DECODE(SUBSTR(t2.NSRZT_DM, 1, 1), '5', '2', '1') AS SYZT, '01' AS SGZT_DM, " +
                    "        SYSDATE AS UPDATE_RQ, '系统' AS UPDATE_USERNAME, 'INSERT' AS CZLX, '税务数据更新_新增税务数据入库' AS BZ " +
                    "FROM (SELECT t.SY_ID, t.BZ AS SWGLM FROM SW_DJ_TD t " +
                    "      UNION " +
                    "      SELECT t.SY_ID, t.BZ AS SWGLM FROM SW_DJ_FC t " +
                    "     ) t " +
                    "     LEFT JOIN SW_DJ_SY t1 ON t.SY_ID=t1.SY_ID " +
                    "     LEFT JOIN SW_DJ_JBB t2 ON t.SWGLM=t2.GLBM " +
                    "WHERE t1.SY_ID IS NULL";
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();

            // 更新土地税修改数据
            tag = "swgxTdsXg";
            sql = tjService.getTjSql(tag);
            sql = "SELECT TD_BM, TDSYZH, TDZL, SCMJ, (SCMJ-NVL(MSMJ,0)) AS YNMJ, MSMJ " +
                    "FROM (" + sql + ")";
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.unwrap(SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
            List<HashMap> listTds = query.getResultList();
            for (HashMap hashMap : listTds) {
                String tdId = hashMap.get("TD_BM").toString();
                queryConditionList.clear();
                queryConditionList.add(new QueryCondition("tdId", QueryCondition.EQ, tdId));
                Object obj = baseRepository.getSingleResult(SwDjTd.class, queryConditionList);
                if (obj == null)
                    continue;
                SwDjTd swDjTd = (SwDjTd)obj;
                if (hashMap.get("TDSYZH") != null)
                    swDjTd.setTdsyzh(hashMap.get("TDSYZH").toString());
                if (hashMap.get("TDZL") != null)
                    swDjTd.setTdzl(hashMap.get("TDZL").toString());
                if (hashMap.get("SCMJ") != null)
                    swDjTd.setScmj(new BigDecimal(hashMap.get("SCMJ").toString()));
                if (hashMap.get("YNMJ") != null)
                    swDjTd.setYnmj(new BigDecimal(hashMap.get("YNMJ").toString()));
                if (hashMap.get("MSMJ") != null)
                    swDjTd.setMsmj(new BigDecimal(hashMap.get("MSMJ").toString()));

                // 保存税源数据
                SwDjSy swDjSy = baseRepository.get(SwDjSy.class, swDjTd.getSyId());
                swDjSy.setBz("税务数据更新_更新土地税修改数据");
                swDjSy.setSwDjTd(swDjTd);
                taxService.updateSwDjSy(swDjSy);
            }

            // 更新房产税修改数据
            tag = "swgxFcsXg";
            sql = tjService.getTjSql(tag);
            sql = "SELECT FY_BM, CQZSH AS FCZH, FWZL AS FCZL, JZ_MJ AS FCMJ, CZ_MJ AS QZCZFCMJ, " +
                    "        YSFCYZ_JE AS FCYZ, YSFCYZ_JE-NVL(MSYZ_JE,0) AS FCYZ_YS, MSYZ_JE AS FCYZ_MS, " +
                    "        JSBL, SL, ROUND((YSFCYZ_JE-NVL(MSYZ_JE,0))*JSBL*SL, 2) AS NYNSE " +
                    "FROM (" + sql + ")";
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.unwrap(SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
            List<HashMap> listFcs = query.getResultList();
            for (HashMap hashMap : listFcs) {
                String fcId = hashMap.get("FY_BM").toString();
                queryConditionList.clear();
                queryConditionList.add(new QueryCondition("fcId", QueryCondition.EQ, fcId));
                Object obj = baseRepository.getSingleResult(SwDjFc.class, queryConditionList);
                if (obj == null)
                    continue;
                SwDjFc swDjFc = (SwDjFc)obj;
                if (hashMap.get("FCZH") != null)
                    swDjFc.setFczh(hashMap.get("FCZH").toString());
                if (hashMap.get("FCZL") != null)
                    swDjFc.setFczl(hashMap.get("FCZL").toString());
                if (hashMap.get("FCMJ") != null)
                    swDjFc.setFcmj(new BigDecimal(hashMap.get("FCMJ").toString()));
                if (hashMap.get("QZCZFCMJ") != null)
                    swDjFc.setQzczfcmj(new BigDecimal(hashMap.get("QZCZFCMJ").toString()));
                if (hashMap.get("FCYZ") != null)
                    swDjFc.setFcyz(new BigDecimal(hashMap.get("FCYZ").toString()));
                if (hashMap.get("FCYZ_YS") != null)
                    swDjFc.setFcyzYs(new BigDecimal(hashMap.get("FCYZ_YS").toString()));
                if (hashMap.get("FCYZ_MS") != null)
                    swDjFc.setFcyzMs(new BigDecimal(hashMap.get("FCYZ_MS").toString()));
                if (hashMap.get("JSBL") != null)
                    swDjFc.setJsbl(new BigDecimal(hashMap.get("JSBL").toString()));
                if (hashMap.get("SL") != null)
                    swDjFc.setSl(new BigDecimal(hashMap.get("SL").toString()));
                if (hashMap.get("NYNSE") != null)
                    swDjFc.setNynse(new BigDecimal(hashMap.get("NYNSE").toString()));
                // 保存税源数据
                SwDjSy swDjSy = baseRepository.get(SwDjSy.class, swDjFc.getSyId());
                swDjSy.setBz("税务数据更新_更新房产税修改数据");
                swDjSy.setSwDjFc(swDjFc);
                taxService.updateSwDjSy(swDjSy);
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        }
    }
}

==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/service/impl/SwgxServiceImpl.java <==
package cn.gtmap.landtax.service.impl;

import cn.gtmap.landtax.entity.SwDjFc;
import cn.gtmap.landtax.entity.SwDjSy;
import cn.gtmap.landtax.entity.SwDjTd;
import cn.gtmap.landtax.service.SwgxService;
import cn.gtmap.landtax.service.TaxService;
import cn.gtmap.landtax.service.TjService;
import cn.gtmap.landtax.support.jpa.BaseRepository;
import cn.gtmap.landtax.util.QueryCondition;
import org.hibernate.SQLQuery;
import org.hibernate.transform.Transformers;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.persistence.Query;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * Created by zenglihuan on 2016-9-16.
 */
@Service
public class SwgxServiceImpl implements SwgxService {
    @Autowired
    BaseRepository baseRepository;
    @Autowired
    TjService tjService;
    @Autowired
    TaxService taxService;

    @Override
    @Transactional
    public void updateSwData() {
        String tag = null;
        String sql = null;
        Query query = null;
        List<QueryCondition> queryConditionList = new ArrayList<QueryCondition>();
        try {
            // 更新纳税人数据
            tag = "swgxNsrXz";
            sql = tjService.getTjSql(tag);
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();

            // 更新土地税新增数据
            tag = "swgxTdsXz";
            sql = tjService.getTjSql(tag);
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();

            // 更新税源主表数据
            /*sql = "INSERT INTO SW_DJ_SY (SYZT, SY_ID, SJLY, BZ) " +
                  "SELECT '1' AS SYZT, t1.SY_ID AS SY_ID, '0' AS SJLY, '税务数据更新_新增税务数据入库' AS BZ " +
                  "FROM SW_DJ_TD t1 " +
                  "LEFT JOIN SW_DJ_SY t2 ON t1.SY_ID=t2.SY_ID " +
                  "WHERE t2.SY_ID IS NULL ";
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();*/

            // 更新土地税修改数据
            tag = "swgxTdsXg";
            sql = tjService.getTjSql(tag);
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();

            // 更新修改数据
            /*tag = "swgxSyXg";
            sql = tjService.getTjSql(tag);
            query = baseRepository.getEntityManager().createNativeQuery(sql);
            query.executeUpdate();*/
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        }
    }
}
